@@ -28,6 +28,7 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <dbus/dbus-glib.h>
 #include <packagekit-glib2/packagekit.h>
 #include <locale.h>
@@ -269,7 +270,7 @@ gpk_window_set_parent_xid (GtkWindow *window, guint32 xid)
 	g_return_val_if_fail (xid != 0, FALSE);
 
 	display = gdk_display_get_default ();
-	parent_window = gdk_window_foreign_new_for_display (display, xid);
+	parent_window = gdk_x11_window_foreign_new_for_display (display, xid);
 	our_window = gtk_widget_get_window (GTK_WIDGET (window));
 
 	/* set this above our parent */
@@ -278,44 +279,100 @@ gpk_window_set_parent_xid (GtkWindow *window, guint32 xid)
 	return TRUE;
 }
 
+/**
+ * gpk_get_pretty_arch:
+ **/
+static const gchar *
+gpk_get_pretty_arch (const gchar *arch)
+{
+	const gchar *id = NULL;
+
+	if (arch[0] == '\0')
+		goto out;
+
+	/* 32 bit */
+	if (g_str_has_prefix (arch, "i")) {
+		id = "32-bit";
+		goto out;
+	}
+
+	/* 64 bit */
+	if (g_str_has_suffix (arch, "64")) {
+		id = "64-bit";
+		goto out;
+	}
+out:
+	return id;
+}
+
 /**
  * gpk_package_id_format_twoline:
  *
  * Return value: "<b>GTK Toolkit</b>\ngtk2-2.12.2 (i386)"
  **/
 gchar *
-gpk_package_id_format_twoline (const gchar *package_id, const gchar *summary)
+gpk_package_id_format_twoline (GtkStyleContext *style,
+			       const gchar *package_id,
+			       const gchar *summary)
 {
-	gchar *summary_safe;
+	gchar *summary_safe = NULL;
 	gchar *text = NULL;
 	GString *string;
 	gchar **split = NULL;
+	gchar *color;
+	const gchar *arch;
+	GdkRGBA inactive;
 
 	g_return_val_if_fail (package_id != NULL, NULL);
 
+	/* get style color */
+	if (style != NULL) {
+		gtk_style_context_get_color (style,
+					     GTK_STATE_FLAG_INSENSITIVE,
+					     &inactive);
+		color = g_strdup_printf ("#%02x%02x%02x",
+					 (guint) (inactive.red * 255.0f),
+					 (guint) (inactive.green * 255.0f),
+					 (guint) (inactive.blue * 255.0f));
+	} else {
+		color = g_strdup ("gray");
+	}
+
 	/* optional */
 	split = pk_package_id_split (package_id);
 	if (split == NULL) {
 		g_warning ("could not parse %s", package_id);
 		goto out;
 	}
-	if (summary == NULL || summary[PK_PACKAGE_ID_NAME] == '\0') {
+
+	/* no summary */
+	if (summary == NULL || summary[0] == '\0') {
 		string = g_string_new (split[PK_PACKAGE_ID_NAME]);
-	} else {
-		string = g_string_new ("");
-		summary_safe = g_markup_escape_text (summary, -1);
-		g_string_append_printf (string, "<b>%s</b>\n%s", summary_safe, split[PK_PACKAGE_ID_NAME]);
-		g_free (summary_safe);
+		if (split[PK_PACKAGE_ID_VERSION][0] != '\0')
+			g_string_append_printf (string, "-%s", split[PK_PACKAGE_ID_VERSION]);
+		arch = gpk_get_pretty_arch (split[PK_PACKAGE_ID_ARCH]);
+		if (arch != NULL)
+			g_string_append_printf (string, " (%s)", arch);
+		text = g_string_free (string, FALSE);
+		goto out;
 	}
 
-	/* some backends don't provide this */
+	/* name and summary */
+	string = g_string_new ("");
+	summary_safe = g_markup_escape_text (summary, -1);
+	g_string_append_printf (string, "%s\n", summary_safe);
+	g_string_append_printf (string, "<span color=\"%s\">", color);
+	g_string_append (string, split[PK_PACKAGE_ID_NAME]);
 	if (split[PK_PACKAGE_ID_VERSION][0] != '\0')
 		g_string_append_printf (string, "-%s", split[PK_PACKAGE_ID_VERSION]);
-	if (split[PK_PACKAGE_ID_ARCH][0] != '\0')
-		g_string_append_printf (string, " (%s)", split[PK_PACKAGE_ID_ARCH]);
-
+	arch = gpk_get_pretty_arch (split[PK_PACKAGE_ID_ARCH]);
+	if (arch != NULL)
+		g_string_append_printf (string, " (%s)", arch);
+	g_string_append (string, "</span>");
 	text = g_string_free (string, FALSE);
 out:
+	g_free (summary_safe);
+	g_free (color);
 	g_strfreev (split);
 	return text;
 }
@@ -628,7 +685,7 @@ gpk_package_entry_completion_get_names_from_file (const gchar *filename)
 			continue;
 		item = pk_package_new ();
 		g_object_set (item,
-			      "info", pk_info_enum_from_text (split[0]),
+			      "info", pk_info_enum_from_string (split[0]),
 			      "package-id", split[1],
 			      "summary", split[2],
 			      NULL);
@@ -875,8 +932,8 @@ gpk_common_test (gpointer data)
 	 ****************     package name text        **************
 	 ************************************************************/
 	egg_test_title (test, "package id pretty valid package id, no summary");
-	text = gpk_package_id_format_twoline ("simon;0.0.1;i386;data", NULL);
-	if (text != NULL && strcmp (text, "simon-0.0.1 (i386)") == 0)
+	text = gpk_package_id_format_twoline (NULL, "simon;0.0.1;i386;data", NULL);
+	if (text != NULL && strcmp (text, "simon-0.0.1 (32-bit)") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "failed, got %s", text);
@@ -884,7 +941,7 @@ gpk_common_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "package id pretty valid package id, no summary 2");
-	text = gpk_package_id_format_twoline ("simon;0.0.1;;data", NULL);
+	text = gpk_package_id_format_twoline (NULL, "simon;0.0.1;;data", NULL);
 	if (text != NULL && strcmp (text, "simon-0.0.1") == 0)
 		egg_test_success (test, NULL);
 	else
@@ -893,7 +950,7 @@ gpk_common_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "package id pretty valid package id, no summary 3");
-	text = gpk_package_id_format_twoline ("simon;;;data", NULL);
+	text = gpk_package_id_format_twoline (NULL, "simon;;;data", NULL);
 	if (text != NULL && strcmp (text, "simon") == 0)
 		egg_test_success (test, NULL);
 	else
@@ -902,8 +959,8 @@ gpk_common_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "package id pretty valid package id, no summary 4");
-	text = gpk_package_id_format_twoline ("simon;0.0.1;;data", "dude");
-	if (text != NULL && strcmp (text, "<b>dude</b>\nsimon-0.0.1") == 0)
+	text = gpk_package_id_format_twoline (NULL, "simon;0.0.1;;data", "dude");
+	if (text != NULL && strcmp (text, "dude\n<span color=\"gray\">simon-0.0.1</span>") == 0)
 		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "failed, got %s", text);
